-- 
-- Please see the license.html file included with this distribution for 
-- attribution and copyright information.
--

function onInit()
	Interface.onDesktopInit = onDesktopInit;

	registerPublicNodes();
	
	OptionsManager.setOptionDefault("DDCL", "desktopdecal_enpublishing");
end

function onDesktopInit()
	buildDesktop();
	
	if not User.isLocal() and not User.isHost() then
		Interface.openWindow("charselect_client", "", true);
	end
end

function registerPublicNodes()
	if User.isHost() then
		DB.createNode("options").setPublic(true);
		DB.createNode("partysheet").setPublic(true);
		DB.createNode("calendar").setPublic(true);
		DB.createNode("combattracker").setPublic(true);
		DB.createNode("modifiers").setPublic(true);
		DB.createNode("effects").setPublic(true);
	end
end

function buildDesktop()
	if User.isLocal() then
		DesktopManager.registerStackShortcuts(aCoreDesktopStack["local"]);
		DesktopManager.registerDockShortcuts(aCoreDesktopDock["local"]);
	elseif User.isHost() then
		DesktopManager.registerStackShortcuts(aCoreDesktopStack["host"]);
		DesktopManager.registerDockShortcuts(aCoreDesktopDock["live"]);
	else
		DesktopManager.registerStackShortcuts(aCoreDesktopStack["client"]);
		DesktopManager.registerDockShortcuts(aCoreDesktopDock["live"]);
	end
end

aCoreDesktopStack = 
{
	["local"] = 
	{
		{
			icon="button_color",
			icon_down="button_color_down",
			tooltipres="sidebar_tooltip_colors",
			class="pointerselection",
		},
	},
	["host"] =
	{
		{
			icon="button_ct",
			icon_down="button_ct_down",
			tooltipres="sidebar_tooltip_ct",
			class="combattracker_host",
			path="combattracker",
		},
		{
			icon="button_partysheet",
			icon_down="button_partysheet_down",
			tooltipres="sidebar_tooltip_ps",
			class="partysheet_host",
			path="partysheet",
		},
		{
			icon="button_calendar",
			icon_down="button_calendar_down",
			tooltipres="sidebar_tooltip_calendar",
			class="calendar",
			path="calendar",
		},
		{
			icon="button_color",
			icon_down="button_color_down",
			tooltipres="sidebar_tooltip_colors",
			class="pointerselection",
		},
		{
			icon="button_light",
			icon_down="button_light_down",
			tooltipres="sidebar_tooltip_lighting",
			class="lightingselection",
		},
		{
			icon="button_options",
			icon_down="button_options_down",
			tooltipres="sidebar_tooltip_options",
			class="options",
		},
		{
			icon="button_modifiers",
			icon_down="button_modifiers_down",
			tooltipres="sidebar_tooltip_modifiers",
			class="modifiers",
			path="modifiers",
		},
		{
			icon="button_effects",
			icon_down="button_effects_down",
			tooltipres="sidebar_tooltip_effects",
			class="effectlist",
			path="effects",
		},
	},
	["client"] =
	{
		{
			icon="button_ct",
			icon_down="button_ct_down",
			tooltipres="sidebar_tooltip_ct",
			class="combattracker_client",
			path="combattracker",
		},
		{
			icon="button_partysheet",
			icon_down="button_partysheet_down",
			tooltipres="sidebar_tooltip_ps",
			class="partysheet_client",
			path="partysheet",
		},
		{
			icon="button_calendar",
			icon_down="button_calendar_down",
			tooltipres="sidebar_tooltip_calendar",
			class="calendar",
			path="calendar",
		},
		{
			icon="button_color",
			icon_down="button_color_down",
			tooltipres="sidebar_tooltip_colors",
			class="pointerselection",
		},
		{
			icon="button_modifiers",
			icon_down="button_modifiers_down",
			tooltipres="sidebar_tooltip_modifiers",
			class="modifiers",
			path="modifiers",
		},
		{
			icon="button_effects",
			icon_down="button_effects_down",
			tooltipres="sidebar_tooltip_effects",
			class="effectlist",
			path="effects",
		},
		{
			icon="button_options",
			icon_down="button_options_down",
			tooltipres="sidebar_tooltip_options",
			class="options",
		},
	},
};

aCoreDesktopDock = 
{
	["local"] =
	{
		{
			icon="button_library",
			icon_down="button_library_down",
			tooltipres="sidebar_tooltip_library",
			class="library",
			subdock = true,
		},
	},
	["live"] =
	{
		{
			icon="button_tokencase",
			icon_down="button_tokencase_down",
			tooltipres="sidebar_tooltip_token",
			class="tokenbag",
			subdock = true,
		},
		{
			icon="button_library",
			icon_down="button_library_down",
			tooltipres="sidebar_tooltip_library",
			class="library",
			subdock = true,
		},
	},
};
